@@ -16,7 +16,7 @@ import os
 import re
 import logging
 
-__version__ = '1.10.16'
+__version__ = '1.12.9'
 
 
 class NullHandler(logging.Handler):
@@ -29,7 +29,6 @@ log.addHandler(NullHandler())
 
 
 _first_cap_regex = re.compile('(.)([A-Z][a-z]+)')
-_number_cap_regex = re.compile('([a-z])([0-9]+)')
 _end_cap_regex = re.compile('([a-z0-9])([A-Z])')
 # The regex below handles the special case where some acryonym
 # name is pluralized, e.g GatewayARNs, ListWebACLs, SomeCNAMEs.
@@ -52,10 +51,6 @@ _xform_cache = {
 # services which might have a matching argument or operation. This way a
 # common mis-translation can be fixed without having to call out each
 # individual case.
-_partial_renames = {
-    'ipv-6': 'ipv6',
-    'ipv_6': 'ipv6',
-}
 ScalarTypes = ('string', 'integer', 'boolean', 'timestamp', 'float', 'double')
 
 BOTOCORE_ROOT = os.path.dirname(os.path.abspath(__file__))
@@ -73,8 +68,7 @@ class UNSIGNED(object):
 UNSIGNED = UNSIGNED()
 
 
-def xform_name(name, sep='_', _xform_cache=_xform_cache,
-               partial_renames=_partial_renames):
+def xform_name(name, sep='_', _xform_cache=_xform_cache):
     """Convert camel case to a "pythonic" name.
 
     If the name contains the ``sep`` character, then it is
@@ -93,12 +87,6 @@ def xform_name(name, sep='_', _xform_cache=_xform_cache,
             # Replace something like ARNs, ACLs with _arns, _acls.
             name = name[:-len(matched)] + sep + matched.lower()
         s1 = _first_cap_regex.sub(r'\1' + sep + r'\2', name)
-        s2 = _number_cap_regex.sub(r'\1' + sep + r'\2', s1)
-        transformed = _end_cap_regex.sub(r'\1' + sep + r'\2', s2).lower()
-
-        # Do partial renames
-        for old, new in partial_renames.items():
-            if old in transformed:
-                transformed = transformed.replace(old, new)
+        transformed = _end_cap_regex.sub(r'\1' + sep + r'\2', s1).lower()
         _xform_cache[key] = transformed
     return _xform_cache[key]
