@@ -35,7 +35,8 @@ class BaseS3OperationTest(BaseSessionTest):
         self.region = 'us-west-2'
         self.client = self.session.create_client(
             's3', self.region)
-        self.session_send_patch = mock.patch('botocore.endpoint.Session.send')
+        # TODO: fix with stubber / before send event
+        self.session_send_patch = mock.patch('botocore.endpoint.Endpoint._send')
         self.http_session_send_mock = self.session_send_patch.start()
 
     def tearDown(self):
@@ -206,7 +207,8 @@ class TestCanSendIntegerHeaders(BaseSessionTest):
     def test_int_values_with_sigv4(self):
         s3 = self.session.create_client(
             's3', config=Config(signature_version='s3v4'))
-        with mock.patch('botocore.endpoint.Session.send') as mock_send:
+        # TODO: fix with stubber / before send event
+        with mock.patch('botocore.endpoint.Endpoint._send') as mock_send:
             mock_send.return_value = mock.Mock(status_code=200,
                                                content=b'',
                                                headers={})
@@ -216,7 +218,7 @@ class TestCanSendIntegerHeaders(BaseSessionTest):
             # Verify that the request integer value of 3 has been converted to
             # string '3'.  This also means we've made it pass the signer which
             # expects string values in order to sign properly.
-            self.assertEqual(headers['Content-Length'], '3')
+            self.assertEqual(headers['Content-Length'], b'3')
 
 
 
@@ -544,6 +546,10 @@ def test_correct_url_used_for_s3():
                  signature_version='s3v4', is_secure=False,
                  expected_url=(
                      'http://bucket.s3.us-west-1.amazonaws.com/key'))
+    yield t.case(
+        region='us-west-1', bucket='bucket-with-num-1', key='key',
+        signature_version='s3v4', is_secure=False,
+        expected_url='http://bucket-with-num-1.s3.us-west-1.amazonaws.com/key')
 
     # Regions outside of the 'aws' partition.
     # These should still default to virtual hosted addressing
@@ -592,6 +598,25 @@ def test_correct_url_used_for_s3():
     yield t.case(
         region='us-east-1', bucket='bucket.dot', key='key',
         expected_url='https://s3.amazonaws.com/bucket.dot/key')
+    yield t.case(
+        region='us-east-1', bucket='BucketName', key='key',
+        expected_url='https://s3.amazonaws.com/BucketName/key')
+    yield t.case(
+        region='us-west-1', bucket='bucket_name', key='key',
+        expected_url='https://s3.us-west-1.amazonaws.com/bucket_name/key')
+    yield t.case(
+        region='us-west-1', bucket='-bucket-name', key='key',
+        expected_url='https://s3.us-west-1.amazonaws.com/-bucket-name/key')
+    yield t.case(
+        region='us-west-1', bucket='bucket-name-', key='key',
+        expected_url='https://s3.us-west-1.amazonaws.com/bucket-name-/key')
+    yield t.case(
+        region='us-west-1', bucket='aa', key='key',
+        expected_url='https://s3.us-west-1.amazonaws.com/aa/key')
+    yield t.case(
+        region='us-west-1', bucket='a'*64, key='key',
+        expected_url=('https://s3.us-west-1.amazonaws.com/%s/key' % ('a' * 64))
+    )
 
     # Custom endpoint url should always be used.
     yield t.case(
@@ -856,7 +881,8 @@ def _verify_expected_endpoint_url(region, bucket, key, s3_config,
         s3 = session.create_client('s3', region_name=region, use_ssl=is_secure,
                                    config=config,
                                    endpoint_url=customer_provided_endpoint)
-        with mock.patch('botocore.endpoint.Session.send') as mock_send:
+        # TODO: fix with stubber / before send event
+        with mock.patch('botocore.endpoint.Endpoint._send') as mock_send:
             mock_send.return_value = http_response
             s3.put_object(Bucket=bucket,
                           Key=key, Body=b'bar')
