@@ -20,7 +20,6 @@ from mock import patch, Mock
 
 from botocore.compat import OrderedDict
 from botocore.handlers import set_list_objects_encoding_type_url
-from botocore.exceptions import UnknownEndpointError
 
 
 class TestS3Addressing(BaseSessionTest):
@@ -41,9 +40,8 @@ class TestS3Addressing(BaseSessionTest):
                              force_hmacv1=False):
         if force_hmacv1:
             self.session.register('choose-signer', self.enable_hmacv1)
-        with patch('botocore.endpoint.PreserveAuthSession') as \
-                mock_http_session:
-            mock_send = mock_http_session.return_value.send
+        # TODO: fix with stubber / before send event
+        with patch('botocore.endpoint.Endpoint._send') as mock_send:
             mock_send.return_value = self.mock_response
             client = self.session.create_client('s3', self.region_name)
             getattr(client, operation)(**params)
@@ -73,7 +71,7 @@ class TestS3Addressing(BaseSessionTest):
         prepared_request = self.get_prepared_request('list_objects', params,
                                                      force_hmacv1=True)
         self.assertEqual(prepared_request.url,
-                         'https://safename.s3.amazonaws.com/')
+                         'https://safename.s3.us-west-2.amazonaws.com/')
 
     def test_list_objects_unicode_query_string_eu_central_1(self):
         self.region_name = 'eu-central-1'
@@ -82,7 +80,7 @@ class TestS3Addressing(BaseSessionTest):
         prepared_request = self.get_prepared_request('list_objects', params)
         self.assertEqual(
             prepared_request.url,
-            ('https://s3.eu-central-1.amazonaws.com/safename'
+            ('https://safename.s3.eu-central-1.amazonaws.com/'
              '?marker=%C3%A4%C3%B6%C3%BC-01.txt')
         )
 
@@ -92,7 +90,7 @@ class TestS3Addressing(BaseSessionTest):
         prepared_request = self.get_prepared_request('list_objects', params)
         # Note how we keep the region specific endpoint here.
         self.assertEqual(prepared_request.url,
-                         'https://s3-us-gov-west-1.amazonaws.com/safename')
+                         'https://safename.s3.us-gov-west-1.amazonaws.com/')
 
     def test_list_objects_in_fips(self):
         self.region_name = 'fips-us-gov-west-1'
@@ -101,14 +99,14 @@ class TestS3Addressing(BaseSessionTest):
         # Note how we keep the region specific endpoint here.
         self.assertEqual(
             prepared_request.url,
-            'https://s3-fips-us-gov-west-1.amazonaws.com/safename')
+            'https://safename.s3-fips-us-gov-west-1.amazonaws.com/')
 
     def test_list_objects_non_dns_name_non_classic(self):
         self.region_name = 'us-west-2'
         params = {'Bucket': 'un_safe_name'}
         prepared_request = self.get_prepared_request('list_objects', params)
         self.assertEqual(prepared_request.url,
-                         'https://s3-us-west-2.amazonaws.com/un_safe_name')
+                         'https://s3.us-west-2.amazonaws.com/un_safe_name')
 
     def test_put_object_dns_name_non_classic(self):
         self.region_name = 'us-west-2'
@@ -126,7 +124,7 @@ class TestS3Addressing(BaseSessionTest):
             prepared_request = self.get_prepared_request('put_object', params)
             self.assertEqual(
                 prepared_request.url,
-                'https://s3-us-west-2.amazonaws.com/my.valid.name/mykeyname')
+                'https://s3.us-west-2.amazonaws.com/my.valid.name/mykeyname')
 
     def test_put_object_dns_name_classic(self):
         self.region_name = 'us-east-1'
@@ -162,7 +160,7 @@ class TestS3Addressing(BaseSessionTest):
             prepared_request = self.get_prepared_request('put_object', params)
             self.assertEqual(
                 prepared_request.url,
-                'https://s3-us-west-2.amazonaws.com/a.valid.name/mykeyname')
+                'https://s3.us-west-2.amazonaws.com/a.valid.name/mykeyname')
 
     def test_get_object_non_dns_name_non_classic(self):
         self.region_name = 'us-west-2'
@@ -173,7 +171,7 @@ class TestS3Addressing(BaseSessionTest):
         prepared_request = self.get_prepared_request('get_object', params)
         self.assertEqual(
             prepared_request.url,
-            'https://s3-us-west-2.amazonaws.com/AnInvalidName/mykeyname')
+            'https://s3.us-west-2.amazonaws.com/AnInvalidName/mykeyname')
 
     def test_get_object_non_dns_name_classic(self):
         self.region_name = 'us-east-1'
@@ -193,7 +191,7 @@ class TestS3Addressing(BaseSessionTest):
         prepared_request = self.get_prepared_request('get_object', params)
         self.assertEqual(
             prepared_request.url,
-            'https://s3-us-west-2.amazonaws.com/192.168.5.4/mykeyname')
+            'https://s3.us-west-2.amazonaws.com/192.168.5.4/mykeyname')
 
     def test_get_object_almost_an_ip_address_name_non_classic(self):
         self.region_name = 'us-west-2'
@@ -203,7 +201,7 @@ class TestS3Addressing(BaseSessionTest):
         prepared_request = self.get_prepared_request('get_object', params)
         self.assertEqual(
             prepared_request.url,
-            'https://s3-us-west-2.amazonaws.com/192.168.5.256/mykeyname')
+            'https://s3.us-west-2.amazonaws.com/192.168.5.256/mykeyname')
 
     def test_invalid_endpoint_raises_exception(self):
         with self.assertRaisesRegexp(ValueError, 'Invalid endpoint'):
